Module protocomm

Module protocomm 

Protocol Communications

Protocomm is a component that can be used for building services with transport independent endpoints for interaction with other applications. It’s architecture is roughly based on Protocomm component in ESP-IDf. You can read more about it here.

By default it provides 2 transports(types of servers): - Https: Uses an HTTP server. - Gatt: Serves a GATT application over BLE.

You can read more information about the transports at ProtocommHttpd and ProtocommGatt

Structs

Protocomm
ProtocommGattConfig

Enums

ProtocommSecurity
Encrypting data in Transit

Type Aliases

ProtocommCallbackType
ProtocommGatt
Protcomm with GATT transport
ProtocommHttpd
Protcomm with HTTP transport
ProtocommHttpdConfig