ProtocommSecurity

Enum ProtocommSecurity 

pub enum ProtocommSecurity {
    Sec0(Sec0),
    Sec1(Box<Sec1>),
}
Encrypting data in Transit

ProtocommSecurity is used for signifying the level of encryption to provide while utilizing Protocomm
It currently provides 2 levels of security:
- Sec0: It provides plaintext communication. Similar to NO ENCRYPTION
- Sec1: It provides transport encryption using AES128-CTR cipher with ECDH using Curve25519 for key exchange. Additionally it is also possible to have a Proof-Of-Possession(PoP) key for added security. PoP is need to be shared by both devices beforehand and is not shared on the communication channel

Variants



Sec0(Sec0)



Sec1(Box<Sec1>)

Implementations