ProtocommGatt

Type Alias ProtocommGatt 

pub type ProtocommGatt = Protocomm<TransportGatt>;
Protcomm with GATT transport

Uses an GATT service for providing interaction with endpoints.

All the registered endpoints are available as GATT characteristics with the UUID specified while registering them.
The caller is responsible for suitable BLE advertisement for this service.

The registered endpoints are made function after calling start().
This should be done after all the required endpoints are registered.
There is no corresponding stop() method. The service stops when the object is dropped

Aliased Type

pub struct ProtocommGatt { /* private fields */ }