ProtocommHttpd

Type Alias ProtocommHttpd 

pub type ProtocommHttpd = Protocomm<TransportHttpd>;
Protcomm with HTTP transport

Uses an HTTP server for providing interaction with endpoints.

All the registered endpoints are available as POST endpoints as “/ep_name”.
The caller is responsible for setting up appropriate mechanism for interacting with this HTTP server.
For e.g., by creating a WiFi Access Point, connecting to a known WiFi network, mDNS etc.

HTTP server is started as soon as it is initialized so the endpoints are available as soon as they are registered.
The service stops when the object is dropped

Aliased Type

pub struct ProtocommHttpd { /* private fields */ }