WifiProvMgr

Struct WifiProvMgr 

pub struct WifiProvMgr<T>{ /* private fields */ }

Implementations

Source

impl WifiProvMgr<WiFiProvTransportSoftAp>

pub fn new( wifi: Arc<Mutex<WifiMgr<'static>>>, config: WiFiProvSoftApConfig, nvs_partition: NvsPartition, sec: ProtocommSecurity, ) -> Result<WiFiProvMgrSoftAp, Error>

Source

impl WifiProvMgr<WiFiProvTransportBle>

pub fn new( wifi: Arc<Mutex<WifiMgr<'static>>>, config: WifiProvBleConfig, nvs_partition: NvsPartition, sec: ProtocommSecurity, ) -> Result<WiFiProvMgrBle, Error>

Source

impl<T: WiFiProvTransportTrait> WifiProvMgr<T>

pub fn wait_for_provisioning(&self)

This function will block until node is not provisioned. It will return once first time WiFi connection has been established using provisioned credentials.

pub fn add_endpoint(&mut self, ep_name: &str, cb: ProtocommCallbackType)

Adding additional endpoints to the pre-existing WiFi provisioning endpoints. It is useful for an endpoint with application specific information and purpose.

pub fn start(&mut self) -> Result<(), Error>

This starts the provisioning process.

pub fn is_provisioned(&self) -> Option<(String, String)>

Checkes if device is already provisioned. If provisioned, it returns the SSID and Password of provisioned WiFi network.