WiFiProvMgrSoftAp

Type Alias WiFiProvMgrSoftAp 

pub type WiFiProvMgrSoftAp = WifiProvMgr<WiFiProvTransportSoftAp>;
SoftAP transport for WiFi Provisioning.

It creates a WiFi access point and uses the Httpd transport provided by Protocomm Each of the endpoint is a HTTP endpoint which can be interacted with using POST requests with necessary data.

Rest of the details are similar to SoftAP transport in Protocomm

Note: For using SoftAp transport on linux, you’ll need to allow opening port 80(or run program as sudo) and externally create a WiFi access point on linux.

Aliased Type

pub struct WiFiProvMgrSoftAp { /* private fields */ }

Implementations