Protocol Communications
Protocomm is a component that can be used for building services with transport independent endpoints for interaction with other applications. It’s architecture is roughly based on Protocomm component in ESP-IDf. You can read more about it here.
By default it provides 2 transports(types of servers): - Https: Uses an HTTP server. - Gatt: Serves a GATT application over BLE.
You can read more information about the transports at ProtocommHttpd and ProtocommGatt
Structs
Enums
- Protocomm
Security - Encrypting data in Transit
Type Aliases
- Protocomm
Callback Type - Protocomm
Gatt - Protcomm with GATT transport
- Protocomm
Httpd - Protcomm with HTTP transport
- Protocomm
Httpd Config