pub struct WifiProvMgr<T>where
T: WiFiProvTransportTrait,{ /* private fields */ }Implementations
Sourceimpl WifiProvMgr<WiFiProvTransportSoftAp>
impl WifiProvMgr<WiFiProvTransportSoftAp>
pub fn new( wifi: Arc<Mutex<WifiMgr<'static>>>, config: WiFiProvSoftApConfig, nvs_partition: NvsPartition, sec: ProtocommSecurity, ) -> Result<WiFiProvMgrSoftAp, Error>
Sourceimpl WifiProvMgr<WiFiProvTransportBle>
impl WifiProvMgr<WiFiProvTransportBle>
pub fn new( wifi: Arc<Mutex<WifiMgr<'static>>>, config: WifiProvBleConfig, nvs_partition: NvsPartition, sec: ProtocommSecurity, ) -> Result<WiFiProvMgrBle, Error>
Sourceimpl<T: WiFiProvTransportTrait> WifiProvMgr<T>
impl<T: WiFiProvTransportTrait> WifiProvMgr<T>
Sourcepub fn wait_for_provisioning(&self)
pub fn wait_for_provisioning(&self)
This function will block until node is not provisioned. It will return once first time WiFi connection has been established using provisioned credentials.
Sourcepub fn add_endpoint(&mut self, ep_name: &str, cb: ProtocommCallbackType)
pub fn add_endpoint(&mut self, ep_name: &str, cb: ProtocommCallbackType)
Adding additional endpoints to the pre-existing WiFi provisioning endpoints. It is useful for an endpoint with application specific information and purpose.
Sourcepub fn is_provisioned(&self) -> Option<(String, String)>
pub fn is_provisioned(&self) -> Option<(String, String)>
Checkes if device is already provisioned. If provisioned, it returns the SSID and Password of provisioned WiFi network.