pub type WiFiProvMgrBle = WifiProvMgr<WiFiProvTransportBle>;Expand description
BLE transport for WiFi Provisioning.
Uses a GATT Service for provisioning purposes. The UUID for this Service is the one provided in the config.
Each of the endpoint is a GATT Characteristic. The UUID for the Characteristic is generated by masking 12th and 13th byte in Service UUID with increasing value for each endpoint registered.
Rest of the details are similar to BLE transport in Protocomm
Note: Bluetooth needs to be turned on on Linux before running the program
Aliased Type
pub struct WiFiProvMgrBle { /* private fields */ }